==> taler-wallet-v0.12.7.tar.gz: taler-wallet-v0.12.7/packages/aml-backoffice-ui/src/hooks/preferences.ts <==
/*
 This file is part of GNU Taler
 (C) 2022-2024 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

import {
  Codec,
  TranslatedString,
  buildCodecForObject,
  codecForBoolean
} from "@gnu-taler/taler-util";
import {
  buildStorageKey,
  useLocalStorage,
  useTranslationContext,
} from "@gnu-taler/web-util/browser";

interface Preferences {
  allowInsecurePassword: boolean;
  keepSessionAfterReload: boolean;
}

export const codecForPreferences = (): Codec<Preferences> =>
  buildCodecForObject<Preferences>()
  .property("allowInsecurePassword", (codecForBoolean()))
  .property("keepSessionAfterReload", (codecForBoolean()))
    .build("Preferences");

const defaultPreferences: Preferences = {
  allowInsecurePassword: false,
  keepSessionAfterReload: false,
};

const PREFERENCES_KEY = buildStorageKey(
  "exchange-preferences",
  codecForPreferences(),
);
/**
 * User preferences.
 *
 * @returns tuple of [state, update()]
 */
export function usePreferences(): [
  Readonly<Preferences>,
  <T extends keyof Preferences>(key: T, value: Preferences[T]) => void,
] {
  const { value, update } = useLocalStorage(
    PREFERENCES_KEY,
    defaultPreferences,
  );

  function updateField<T extends keyof Preferences>(k: T, v: Preferences[T]) {
    const newValue = { ...value, [k]: v };
    update(newValue);
  }
  return [value, updateField];
}

export function getAllBooleanPreferences(): Array<keyof Preferences> {
  return [
    "allowInsecurePassword",
    "keepSessionAfterReload",
  ];
}

export function getLabelForPreferences(
  k: keyof Preferences,
  i18n: ReturnType<typeof useTranslationContext>["i18n"],
): TranslatedString {
  switch (k) {
    case "allowInsecurePassword": return i18n.str`Allow Insecure password`
    case "keepSessionAfterReload": return i18n.str`Keep session after reload`
  }
}

==> taler-wallet-v0.13.1.tar.gz: taler-wallet-v0.13.1/packages/aml-backoffice-ui/src/hooks/preferences.ts <==
/*
 This file is part of GNU Taler
 (C) 2022-2024 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

import {
  Codec,
  TranslatedString,
  buildCodecForObject,
  codecForBoolean
} from "@gnu-taler/taler-util";
import {
  buildStorageKey,
  useLocalStorage,
  useTranslationContext,
} from "@gnu-taler/web-util/browser";

interface Preferences {
  showDebugInfo: boolean;
  allowInsecurePassword: boolean;
  keepSessionAfterReload: boolean;
}

export const codecForPreferences = (): Codec<Preferences> =>
  buildCodecForObject<Preferences>()
  .property("allowInsecurePassword", (codecForBoolean()))
  .property("showDebugInfo", codecForBoolean())
  .property("keepSessionAfterReload", (codecForBoolean()))
    .build("Preferences");

const defaultPreferences: Preferences = {
  allowInsecurePassword: false,
  showDebugInfo: false,
  keepSessionAfterReload: false,
};

const PREFERENCES_KEY = buildStorageKey(
  "aml-preferences",
  codecForPreferences(),
);
/**
 * User preferences.
 *
 * @returns tuple of [state, update()]
 */
export function usePreferences(): [
  Readonly<Preferences>,
  <T extends keyof Preferences>(key: T, value: Preferences[T]) => void,
] {
  const { value, update } = useLocalStorage(
    PREFERENCES_KEY,
    defaultPreferences,
  );

  function updateField<T extends keyof Preferences>(k: T, v: Preferences[T]) {
    const newValue = { ...value, [k]: v };
    update(newValue);
  }
  return [value, updateField];
}

export function getAllBooleanPreferences(): Array<keyof Preferences> {
  return [
    "showDebugInfo",
    "allowInsecurePassword",
    "keepSessionAfterReload",
  ];
}

export function getLabelForPreferences(
  k: keyof Preferences,
  i18n: ReturnType<typeof useTranslationContext>["i18n"],
): TranslatedString {
  switch (k) {
    case "showDebugInfo": return i18n.str`Show debug info`
    case "allowInsecurePassword": return i18n.str`Allow Insecure password`
    case "keepSessionAfterReload": return i18n.str`Keep session after reload`
  }
}
